/*
 * Copyright (c) 2013      Mellanox Technologies, Inc.
 *                         All rights reserved.
 * $COPYRIGHT$
 *
 * Additional copyrights may follow
 *
 * $HEADER$
 */
/**
 *  @file
 */

#ifndef MCA_SPML_IKRIT_COMPONENT_H
#define MCA_SPML_IKRIT_COMPONENT_H

BEGIN_C_DECLS

/*
 * SPML module functions.
 */
OSHMEM_MODULE_DECLSPEC extern mca_spml_base_component_2_0_0_t mca_spml_ikrit_component;
END_C_DECLS

#endif
